==> jc-1.4.0.tar.gz: java/awt/event/ContainerAdapter.h <==
// public abstract class java.awt.event.ContainerAdapter

// class file dependencies
// @dep_class 13e2695eacb9e7a3 java_awt_event_ContainerAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_ContainerAdapter_H_
#define _JC_java_awt_event_ContainerAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_ContainerAdapter$sub_refs	_jc_java_awt_event_ContainerAdapter$sub_refs;
typedef struct _jc_java_awt_event_ContainerAdapter$sub_nonrefs	_jc_java_awt_event_ContainerAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_ContainerAdapter$refs	_jc_java_awt_event_ContainerAdapter$refs;
typedef struct _jc_java_awt_event_ContainerAdapter$nonrefs	_jc_java_awt_event_ContainerAdapter$nonrefs;
typedef struct _jc_java_awt_event_ContainerAdapter$object	_jc_java_awt_event_ContainerAdapter$object;

typedef const struct _jc_java_awt_event_ContainerAdapter$vmethods	_jc_java_awt_event_ContainerAdapter$vmethods;
typedef const struct _jc_java_awt_event_ContainerAdapter$vtable	_jc_java_awt_event_ContainerAdapter$vtable;
typedef const struct _jc_java_awt_event_ContainerAdapter$vtype	_jc_java_awt_event_ContainerAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_ContainerAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *);

// Virtual methods
extern void _jc_java_awt_event_ContainerAdapter$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *);
extern void _jc_java_awt_event_ContainerAdapter$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ContainerAdapter$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_java_awt_event_ContainerAdapter$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_java_awt_event_ContainerAdapter$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *);
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *);
};

// Vtable
struct _jc_java_awt_event_ContainerAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_ContainerAdapter$vmethods	java_awt_event_ContainerAdapter;
};

// Vtype
struct _jc_java_awt_event_ContainerAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_ContainerAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ContainerAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_ContainerAdapter$refs {
    _jc_java_awt_event_ContainerAdapter$sub_refs	java_awt_event_ContainerAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ContainerAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ContainerAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_ContainerAdapter$sub_nonrefs	java_awt_event_ContainerAdapter;
};

// Object instance structure
struct _jc_java_awt_event_ContainerAdapter$object {
	_jc_java_awt_event_ContainerAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ContainerAdapter$vtype	*vtype;
	_jc_java_awt_event_ContainerAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ContainerAdapter$vtype _jc_java_awt_event_ContainerAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ContainerAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ContainerAdapter$class_object;

#endif	/* _JC_java_awt_event_ContainerAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/event/ContainerAdapter.h <==
// public abstract class java.awt.event.ContainerAdapter

// class file dependencies
// @dep_class 13e2695eacb9e7a3 java_awt_event_ContainerAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_ContainerAdapter_H_
#define _JC_java_awt_event_ContainerAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_ContainerAdapter$sub_refs	_jc_java_awt_event_ContainerAdapter$sub_refs;
typedef struct _jc_java_awt_event_ContainerAdapter$sub_nonrefs	_jc_java_awt_event_ContainerAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_ContainerAdapter$refs	_jc_java_awt_event_ContainerAdapter$refs;
typedef struct _jc_java_awt_event_ContainerAdapter$nonrefs	_jc_java_awt_event_ContainerAdapter$nonrefs;
typedef struct _jc_java_awt_event_ContainerAdapter$object	_jc_java_awt_event_ContainerAdapter$object;

typedef const struct _jc_java_awt_event_ContainerAdapter$vmethods	_jc_java_awt_event_ContainerAdapter$vmethods;
typedef const struct _jc_java_awt_event_ContainerAdapter$vtable	_jc_java_awt_event_ContainerAdapter$vtable;
typedef const struct _jc_java_awt_event_ContainerAdapter$vtype	_jc_java_awt_event_ContainerAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_ContainerAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_ContainerAdapter$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_ContainerAdapter$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ContainerAdapter$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_java_awt_event_ContainerAdapter$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_java_awt_event_ContainerAdapter$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_java_awt_event_ContainerAdapter$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_ContainerAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_ContainerAdapter$vmethods	java_awt_event_ContainerAdapter;
};

// Vtype
struct _jc_java_awt_event_ContainerAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_ContainerAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ContainerAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_ContainerAdapter$refs {
    _jc_java_awt_event_ContainerAdapter$sub_refs	java_awt_event_ContainerAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ContainerAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ContainerAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_ContainerAdapter$sub_nonrefs	java_awt_event_ContainerAdapter;
};

// Object instance structure
struct _jc_java_awt_event_ContainerAdapter$object {
	_jc_java_awt_event_ContainerAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ContainerAdapter$vtype	*vtype;
	_jc_java_awt_event_ContainerAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ContainerAdapter$vtype _jc_java_awt_event_ContainerAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ContainerAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ContainerAdapter$class_object;

#endif	/* _JC_java_awt_event_ContainerAdapter_H_ */
